@@ -221,7 +221,7 @@ class Reporter(object):
                     </td>
                     <td>
                         <table border='0' class="table table-hover">
-                            <tr style='background-color: whitesmoke;'>
+                            <tr style='background-color: whitesmoke; min-width: 580px;'>
                                 <th>Execution Start Time</th>
                                 <td align="center">%s</td>
                             </tr>
@@ -262,7 +262,7 @@ class Reporter(object):
                 </tr>
             </table>
             """ % (
-                datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S %p"),
+                start_time.strftime("%Y-%m-%d %H:%M:%S %p"),
                 execution_time,
                 len(passed_cases) + failed_cases_count,
                 len(passed_cases),
