@@ -1,5 +1,5 @@
 import os
-
+import json as json_func
 import requests
 import settings
 
@@ -159,7 +159,8 @@ class LoggedRequests:
 
         if data is not None:
             self.logger.info(os.linesep + "------------ data start:")
-            self.logger.info(os.linesep + self.pformat(data))
+            # self.logger.info(os.linesep + self.pformat(data))
+            self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
             self.logger.info(os.linesep + "------------ data end -------" + os.linesep)
 
         if json is not None:
@@ -217,7 +218,8 @@ class LoggedRequests:
 
         if data is not None:
             self.logger.info(os.linesep + "------------ data:")
-            self.logger.info(os.linesep + self.pformat(data))
+            # self.logger.info(os.linesep + self.pformat(data))
+            self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
 
         if len(kwargs.keys()) > 0:
             self.logger.info(os.linesep + "------------ kwargs:")
